Using Sorcha Community Utils
============================

In order to use the community utilities, first install this package in your
virtual environment.

.. code:: bash

    >> pip install sorcha-addons

Once the ``sorcha-addons`` is installed, Sorcha will automatically detect 
the available plugins and make them available during processing.

To use one of the plugins from the community utilities, simply add the unique
name of the plugin to the configuration file provided to Sorcha, and provide the
complex parameters file on the command line.

For more information about running Sorcha, the configuration file, and providing 
arguments on the command line, see the documentation available 
`here <https://sorcha.readthedocs.io/en/latest/gettingstarted.html#setting-up-sorcha-s-configuration-file>`_.